###################################################
### chunk number 1: options
###################################################

options(width=80)
library(XML)



###################################################
### chunk number 2: readGSE350
###################################################

gse350Dir <- file.path("RawData","GEO","GSE350")
gse350Xml <- xmlTreeParse(file.path(gse350Dir, "GSE350_family.xml"))
gse350Root <- xmlRoot(gse350Xml)
xmlSize(gse350Root)
table(xmlSApply(gse350Root, xmlName))

xmlValue(gse350Root[[which(xmlSApply(gse350Root, xmlName) == 
                           "Series")]][["Summary"]])

idxSample <- which(xmlSApply(gse350Root, xmlName) == "Sample")
gse350Root[[idxSample[1]]]



###################################################
### chunk number 3: grabGSE350Info
###################################################

tempSampleNames <- sapply(idxSample, function(x){
  xmlValue(gse350Root[[x]][["Title"]])})

tempGSMID <- sapply(idxSample, function(x){
  xmlValue(gse350Root[[x]][["Accession"]])})

tempDataFile <- sapply(idxSample, function(x){
  xmlValue(gse350Root[[x]][["Data-Table"]][["External-Data"]])})

tempStatus <- rep("Sensitive", length(tempGSMID))

gse350Info <- 
  data.frame(row.names = tempGSMID,
             dataFile = I(tempDataFile),
             sampleName = I(tempSampleNames),
             status = I(tempStatus))

rm(list = ls(pattern = "^temp"))



###################################################
### chunk number 4: listGSE350Info
###################################################

gse350Info



###################################################
### chunk number 5: readQuants
###################################################

tempTable <- read.table(file.path(gse350Dir, gse350Info[1,"dataFile"]),
                        row.names = 1)
gse350 <- matrix(0, nrow = dim(tempTable)[1], ncol=dim(gse350Info)[1])
rownames(gse350) <- rownames(tempTable)
colnames(gse350) <- rownames(gse350Info)
gse350[,1] <- tempTable[,1]
for(tempSample in 2:dim(gse350Info)[1]){
  tempTable <- 
    read.table(file.path(gse350Dir, gse350Info[tempSample,"dataFile"]),
               row.names = 1)
  if(all(rownames(tempTable) == rownames(gse350))){
    gse350[,tempSample] <- tempTable[,1]
  }
}
rm(list = ls(pattern = "^temp"))



###################################################
### chunk number 6: checkFirstFew
###################################################

dim(gse350)
gse350[1:3,]
apply(gse350,2,min)



###################################################
### chunk number 7: saveStuff
###################################################

save(gse350, gse350Info,
     file=file.path("RDataObjects","gse350.Rda"))



###################################################
### chunk number 8: getLocation
###################################################

getwd()



###################################################
### chunk number 9: saveStuff
###################################################



###################################################
### chunk number 10: sessionInfo
###################################################

sessionInfo();



