###################################################
### chunk number 1: options
###################################################

options(width=80)



###################################################
### chunk number 2: loadEarlierRdas
###################################################

rdaList <- c("novartisAll")
for(rdaFile in rdaList){
  rdaFullFile <- 
    file.path("RDataObjects",paste(rdaFile,"Rda",sep="."))
  if(file.exists(rdaFullFile)){
    cat("loading ",rdaFullFile, " from cache\n")
    load(rdaFullFile)
  }else{
    cat("building ",rdaFullFile, " from raw data\n")
    Stangle(file.path("RNowebSource",
                      paste("buildRda",rdaFile,"Rnw",sep=".")))
    source(paste("buildRda",rdaFile,"R",sep="."))
  }
}



###################################################
### chunk number 3: loadNCI60Info
###################################################

nci60Info <- 
  read.table(file.path("RawData","NCI60","nci60Info.csv"),
             sep=",",header=TRUE, 
             colClasses=c("character","character","numeric","numeric"),
             row.names=1)
nci60Info[1:3,]



###################################################
### chunk number 4: loadRecentLists
###################################################

signatureCellLines <- 
  read.table(file.path("RawData","PottiNatMed",
                       "cellLinesInEachPredictor1_reorg.csv"),
             header=TRUE, sep=",")
signatureCellLines[1:3,]

which(is.na(match(signatureCellLines[,"CellLine"],rownames(nci60Info))))
dim(signatureCellLines)
signatureCellLines[123:124,]

signatureCellLines[124,"CellLine"] <- "OVCAR-8"
signatureCellLines[,"CellLine"] <- 
  as.factor(as.character(signatureCellLines[,"CellLine"]))



###################################################
### chunk number 5: getPanelOrder
###################################################

panelNumbers <- 
  tapply(nci60Info[as.character(signatureCellLines[,"CellLine"]),"PANELNBR"],
         signatureCellLines[,c("Status","Drug")],
         FUN=function(x){x})
panelNumbers["Resistant",]
panelNumbers["Sensitive",]



###################################################
### chunk number 6: checkLeukemiaOrder
###################################################

nci60Info[nci60Info[,"PANELNBR"]==7,]
signatureCellLines[nci60Info[as.character(signatureCellLines[,"CellLine"]),
                             "PANELNBR"]==7,]



###################################################
### chunk number 7: checkCNSOrder
###################################################

nci60Info[nci60Info[,"PANELNBR"]==12,]
signatureCellLines[nci60Info[as.character(signatureCellLines[,"CellLine"]),
                             "PANELNBR"]==12,]



###################################################
### chunk number 8: checkBreastOrder
###################################################

nci60Info[nci60Info[,"PANELNBR"]==5,]
signatureCellLines[nci60Info[as.character(signatureCellLines[,"CellLine"]),
                             "PANELNBR"]==5,]



###################################################
### chunk number 9: checkColonOrder
###################################################

nci60Info[nci60Info[,"PANELNBR"]==4,]
signatureCellLines[nci60Info[as.character(signatureCellLines[,"CellLine"]),
                             "PANELNBR"]==4,]



###################################################
### chunk number 10: checkNSCLCOrder
###################################################

nci60Info[nci60Info[,"PANELNBR"]==1,]
signatureCellLines[nci60Info[as.character(signatureCellLines[,"CellLine"]),
                             "PANELNBR"]==1,]



###################################################
### chunk number 11: checkMelanomaOrder
###################################################

nci60Info[nci60Info[,"PANELNBR"]==10,]
signatureCellLines[nci60Info[as.character(signatureCellLines[,"CellLine"]),
                             "PANELNBR"]==10,]



###################################################
### chunk number 12: checkOvarianOrder
###################################################

nci60Info[nci60Info[,"PANELNBR"]==6,]
signatureCellLines[nci60Info[as.character(signatureCellLines[,"CellLine"]),
                             "PANELNBR"]==6,]



###################################################
### chunk number 13: checkProstateOrder
###################################################

nci60Info[nci60Info[,"PANELNBR"]==11,]
signatureCellLines[nci60Info[as.character(signatureCellLines[,"CellLine"]),
                             "PANELNBR"]==11,]



###################################################
### chunk number 14: checkRenalOrder
###################################################

nci60Info[nci60Info[,"PANELNBR"]==9,]
signatureCellLines[nci60Info[as.character(signatureCellLines[,"CellLine"]),
                             "PANELNBR"]==9,]



###################################################
### chunk number 15: finalNovAOrder
###################################################

tempOrder <- 
  c("CCRF-CEM",        "K-562",           "MOLT-4",          "HL-60(TB)",      
    "RPMI-8226",       "SR",              "SF-268",          "SF-295",         
    "SF-539",          "SNB-19",          "SNB-75",          "U251",           
    "BT-549",          "HS 578T",         "MCF7",            "MDA-MB-231/ATCC",
    "NCI/ADR-RES",     "MDA-MB-435",      "T-47D",           "COLO 205",       
    "HCC-2998",        "HCT-116",         "HCT-15",          "HT29",           
    "KM12",            "SW-620",          "A549/ATCC",       "EKVX",           
    "HOP-62",          "HOP-92",          "NCI-H226",        "NCI-H23",        
    "NCI-H322M",       "NCI-H460",        "NCI-H522",        "LOX IMVI",       
    "M14",             "MALME-3M",        "SK-MEL-2",        "SK-MEL-28",      
    "SK-MEL-5",        "UACC-257",        "UACC-62",         "DU-145",         
    "PC-3",            "IGROV1",          "OVCAR-3",         "OVCAR-4",        
    "OVCAR-5",         "OVCAR-8",         "SK-OV-3",         "786-0",          
    "A498",            "ACHN",            "CAKI-1",          "RXF 393",        
    "SN12C",           "TK-10",           "UO-31")          



###################################################
### chunk number 16: extractQuantifications
###################################################

novartisA <- novartisAll[,grep("A$",colnames(novartisAll))]
colnames(novartisA) <- 
  substr(colnames(novartisA),1,nchar(colnames(novartisA))-2)
novartisA <- novartisA[,tempOrder]
dim(novartisA)
novartisA[1:3,1:3]



###################################################
### chunk number 17: reorderInfo
###################################################

novartisAInfo <- nci60Info[colnames(novartisA),]



###################################################
### chunk number 18: saveRda
###################################################

save(novartisA, novartisAInfo,
     file=file.path("RDataObjects","novartisA.Rda"))



###################################################
### chunk number 19: getLocation
###################################################

getwd()



###################################################
### chunk number 20: saveStuff
###################################################




###################################################
### chunk number 21: sessionInfo
###################################################

sessionInfo();



