###################################################
### chunk number 1: options
###################################################

options(width=80);



###################################################
### chunk number 2: loadData
###################################################

rdaList <- c("novartisA","changSuppAndTable","changAll","cellLinesUsed")
for(rdaFile in rdaList){
  rdaFullFile <- 
    file.path("RDataObjects",paste(rdaFile,"Rda",sep="."))
  if(file.exists(rdaFullFile)){
    cat("loading ",rdaFullFile, " from cache\n")
    load(rdaFullFile)
  }else{
    cat("building ",rdaFullFile, " from raw data\n")
    Stangle(file.path("RNowebSource",
                      paste("buildRda",rdaFile,"Rnw",sep=".")))
    source(paste("buildRda",rdaFile,"R",sep="."))
  }
}



###################################################
### chunk number 3: loadChangClinical
###################################################

changClinicalPotti07 <- 
  read.table(file.path("RawData", "PottiNatMed","changClinicalDataPotti07.csv"),
             sep=",",header=TRUE)
dim(changClinicalPotti07)
changClinicalPotti07[1:2,]



###################################################
### chunk number 4: loadDoce07
###################################################

tempDocetaxel07Header1 <- 
  read.table(file.path("RawData","PottiNatMed","BreastData.txt"), sep="\t",
             nrows=1, header=FALSE)
tempDocetaxel07Header1 <- as.vector(t(tempDocetaxel07Header1));

tempDocetaxel07Header2 <- 
  read.table(file.path("RawData","PottiNatMed","BreastData.txt"), sep="\t",
             skip=1, nrows=1, header=FALSE)
tempDocetaxel07Header2 <- as.vector(t(tempDocetaxel07Header2));

tempDocetaxel07Header1
tempDocetaxel07Header2

table(tempDocetaxel07Header1[1:14],tempDocetaxel07Header2[1:14])
table(tempDocetaxel07Header1[15:38],tempDocetaxel07Header2[15:38])



###################################################
### chunk number 5: buildDoce07Info
###################################################

tempSampleNames <- 
  c(paste("Training", c(1:14), sep=""), 
    paste("Test", c(1:24), sep=""))

tempGroup <- c(rep("Training", 14), rep("Test", 24))
tempStatus <- tempDocetaxel07Header2

docetaxel07Info <- 
  data.frame(sampleGroup = tempGroup,
             status      = tempStatus,
             row.names   = tempSampleNames)

docetaxel07Info[c(1:2,14:16),]

rm(list=ls(pattern="^temp"))



###################################################
### chunk number 6: loadDoce07Numbers
###################################################

docetaxel07Numbers <- 
  read.table(file.path("RawData","PottiNatMed","BreastData.txt"), sep="\t",
             skip=2, header=FALSE)

colnames(docetaxel07Numbers) <- rownames(docetaxel07Info)

docetaxel07Numbers[1:4,c(1:2,14:16)]



###################################################
### chunk number 7: loadChangClinical08
###################################################

changClinicalPotti08 <- 
  read.table(file.path("RawData","PottiNatMed","changClinicalDataPotti08.csv"),
             sep=",",header=TRUE, nrows=24)
dim(changClinicalPotti08)
changClinicalPotti08[1:2,]



###################################################
### chunk number 8: checkTable1Match
###################################################

all(changTable1 == changClinicalPotti07[,1:10])



###################################################
### chunk number 9: checkSensResLabels
###################################################

tempBadRows <- 
  which(as.character(
      changClinicalPotti07[,"Sens.or.Res..S.is.less.than.40pct."]) !=
      substr(as.character(changSuppClinical[,"Status"]),1,1))      
changClinicalPotti07[tempBadRows,"Sens.or.Res..S.is.less.than.40pct."]
changSuppClinical[tempBadRows,]



###################################################
### chunk number 10: checkPercentTumor
###################################################

which(changClinicalPotti07[,"Percent.Residual.Tumor"] !=
      changSuppClinical[,"PercentResidualTumor"])
changClinicalPotti07[13:15,
  c("Patient","Percent.Residual.Tumor","Sens.or.Res..S.is.less.than.40pct.")]
changSuppClinical[13:15,]



###################################################
### chunk number 11: getDoceQuants
###################################################

cellLinesUsed[["docetaxel"]][["listPotti06CorrAug08"]]



###################################################
### chunk number 12: getDoceQuants
###################################################

docetaxelNCI60Quants <- 
  novartisA[,c(cellLinesUsed[["docetaxel"]][[
                             "listPotti06CorrAug08"]][["Resistant"]],
               cellLinesUsed[["docetaxel"]][[
                             "listPotti06CorrAug08"]][["Sensitive"]])]
docetaxelNCI60Quants <- 
  docetaxelNCI60Quants[-grep("^AFFX",rownames(docetaxelNCI60Quants)),]



###################################################
### chunk number 13: checkRange
###################################################

range(docetaxel07Numbers[,1:14])



###################################################
### chunk number 14: checkAfterLog
###################################################

mean(log(t(docetaxel07Numbers[1,1:14])))
var(log(t(docetaxel07Numbers[1,1:14])))



###################################################
### chunk number 15: tryToMatchAll
###################################################

tempDoceStandardized <- exp(t(scale(t(log(docetaxelNCI60Quants)))))
summary(apply(abs(tempDoceStandardized - docetaxel07Numbers[,1:14]),1,max))



###################################################
### chunk number 16: matchInfo
###################################################

cbind(docetaxel07Info[1:14,], colnames(docetaxelNCI60Quants))



###################################################
### chunk number 17: standardizeChang
###################################################

changGEOStandardized <- 
  round(exp(t(scale(t(log(changAll[rownames(docetaxelNCI60Quants),]))))),2);
sum(is.na(changGEOStandardized))
tempBadRows <- unique(which(is.na(changGEOStandardized),arr.ind=TRUE)[,"row"])
tempBadRows



###################################################
### chunk number 18: examineBad
###################################################

#summary(unlist(changAll[rownames(changGEOStandardized)[tempBadRows],]))
summary(as.vector(changAll[rownames(changGEOStandardized)[tempBadRows],]))
summary(unlist(docetaxel07Numbers[tempBadRows,15:38]))



###################################################
### chunk number 19: standardizeChangPart2
###################################################

changGEOStandardized[is.na(changGEOStandardized)] <- 2.66



###################################################
### chunk number 20: getChangCors
###################################################

pottiGEOCorrs <- 
  cor(docetaxel07Numbers[,15:38], 
      changGEOStandardized)
pottiGEOCorrs[1:3,1:3]
summary(pottiGEOCorrs[,1])
sum(pottiGEOCorrs > 0.9999)



###################################################
### chunk number 21: drawPottiGEOFigure
###################################################

image(1:24, 1:24, pottiGEOCorrs < 0.9999, axes=FALSE, xlab="", ylab="",
      asp=1,main="Corrs > 0.9999 Between Potti and GEO");
lines(c(0.5,24.5),c(11.5,11.5))
lines(c(11.5,11.5),c(0.5,24.5))
rect(0.5,0.5,24.5,24.5)
axis(1, at=1:24, labels=rownames(pottiGEOCorrs), las=2, line=-0.5, tick=0);
axis(2, at=1:24, labels=colnames(pottiGEOCorrs), las=2, line=-2.1, tick=0);
lines(c(0.5,24.5),c(11,11),lty="dashed")
lines(c(0.5,24.5),c(21,21),lty="dashed")
axis(3,at=c(6,18),labels=c("Resistant (Potti)","Sensitive (Potti)"),
     tick=0,line=-0.8)
axis(4,at=c(6,18),labels=c("Sensitive (Chang)","Resistant (Chang)"),
     tick=0,line=-2)
axis(2,at=c(12,13),labels=c("S* (N12)","S* (N13)"),las=2,line=-6,tick=0)
changAllInfo[c("N21","N11"),1:4]



###################################################
### chunk number 22: compareMappings
###################################################

cbind(changClinicalPotti08[,c("Percent.Residual.Tumor","GEO.Identifier")], 
      changAllInfo[,"geoID"])
sum(as.character(changClinicalPotti08$GEO.Identifier) == 
    as.character(changAllInfo[,"geoID"]))
sum(sort(as.character(changClinicalPotti08$GEO.Identifier)[1:13]) == 
    sort(as.character(changAllInfo[1:13,"geoID"])))
sum(sort(as.character(changClinicalPotti08$GEO.Identifier)[14:24]) == 
    sort(as.character(changAllInfo[14:24,"geoID"])))



###################################################
### chunk number 23: loadSampleInfo
###################################################

tempInfoPart1 <- 
  read.table(file.path("MatlabFiles","DocetaxelSimulations",
                       "DoceTrainAndTestSampleInfo.csv"),
             sep=",",header=TRUE,nrows=14)
tempInfoPart2 <- 
  read.table(file.path("MatlabFiles","DocetaxelSimulations",
                       "DoceTrainAndTestSampleInfo.csv"),
             sep=",",header=TRUE,skip=15)
tempInfoPart1[1:3,]
tempInfoPart2[1:3,]
doceSimulationStatus <- 
  c(as.character(tempInfoPart1$responseStatus),
    as.character(tempInfoPart2$Response))
names(doceSimulationStatus) <-
  c(as.character(tempInfoPart1$Source),
    as.character(tempInfoPart2$GEO.ID))



###################################################
### chunk number 24: readBaseIndices
###################################################

baseProbesetIndices <- 
  read.table(file.path("MatlabFiles","DocetaxelSimulations",
                       "baseProbesetIndices.csv"), header=FALSE, sep=",")
baseProbesetIndices <- as.matrix(baseProbesetIndices)
baseProbesetIndices <- t(apply(baseProbesetIndices,1,sort))
rownames(baseProbesetIndices) <- paste("simulation",c(1:100),sep="")
colnames(baseProbesetIndices) <- paste("geneIndex",c(1:50),sep="")
baseProbesetIndices[1:3,1:3]
all(baseProbesetIndices == 
    matrix(rep(baseProbesetIndices["simulation1",],100),ncol=50,byrow=TRUE))



###################################################
### chunk number 25: readBasePfits
###################################################

basePfitVectors <- 
  read.table(file.path("MatlabFiles","DocetaxelSimulations",
                       "basePfitVectors.csv"), header=FALSE, sep=",")
colnames(basePfitVectors) <- names(doceSimulationStatus)
rownames(basePfitVectors) <- paste("simulation",c(1:100),sep="")



###################################################
### chunk number 26: plotBaselinePfits
###################################################

matplot(t(basePfitVectors),pch="o",col="black",cex=0.5,xlim=c(0.5,38.5),
        xaxt="n", xlab="True Sample Status",
        ylab="Probability of Response",
        main="Predicted Response to Docetaxel, 100 Simulations")
abline(h=0.5,v=c(14.5),col="red",lwd=2)
abline(v=c(7.5,25.5),col="red",lty="dashed")
axis(side=1,at=c(4,11,20,32),
     labels=c("Resistant","Sensitive","Resp","NR"),tick=0,line=-1)
axis(side=3,at=c(7.5,26.5),
     labels=c("Training Cell Lines", "Test Samples"),tick=0,line=-1)
axis(side=4,at=c(0.25,0.75),labels=c("Call: Resistant","Call: Sensitive"),
     tick=FALSE,line=-1)



###################################################
### chunk number 27: checkBaseConsistency
###################################################

apply(basePfitVectors,2,function(x){sum(x>0.5)})
table(doceSimulationStatus,basePfitVectors[1,] > 0.5)



###################################################
### chunk number 28: loadNullCellLines
###################################################

nullCellLineIndices <- 
  read.table(file.path("MatlabFiles","DocetaxelSimulations",
                       "nullCellLineIndices.csv"), header=FALSE, sep=",")
nullCellLineIndices <- as.matrix(nullCellLineIndices)
rownames(nullCellLineIndices) <- paste("nullSim",c(1:1000),sep="")
colnames(nullCellLineIndices) <- 
  c(paste("cellLineResIndex",c(1:7),sep=""),
    paste("cellLineSenIndex",c(1:7),sep=""))
nullCellLineIndices[1:3,1:3]



###################################################
### chunk number 29: loadNullPfits
###################################################

nullPfitVectors <- 
  read.table(file.path("MatlabFiles","DocetaxelSimulations",
                       "nullTrainAndTestPfitVectors.csv"), 
             header=FALSE, sep=",")
colnames(nullPfitVectors) <- 
  c(paste("nullRes",c(1:7),sep=""), paste("nullSim",c(1:7),sep=""),
    paste("testResp",c(1:11),sep=""), paste("testNR",c(1:13),sep=""))
rownames(nullPfitVectors) <- paste("nullSim",c(1:1000),sep="")

nullNRespCorrect <- 
  apply(nullPfitVectors[,15:25],1,function(x){sum(x > 0.5)})
nullNNRCorrect <- 
  apply(nullPfitVectors[,26:38],1,function(x){sum(x < 0.5)})
nullNCorrect <- nullNRespCorrect + nullNNRCorrect

table(nullNCorrect)
sum(nullNCorrect >= 11)



###################################################
### chunk number 30: readSR9Indices
###################################################

sr9ProbesetIndices <- 
  read.table(file.path("MatlabFiles","DocetaxelSimulations",
                       "sr9ProbesetIndices.csv"), header=FALSE, sep=",")
sr9ProbesetIndices <- as.matrix(sr9ProbesetIndices)
sr9ProbesetIndices <- t(apply(sr9ProbesetIndices,1,sort))
rownames(sr9ProbesetIndices) <- paste("simulation",c(1:100),sep="")
colnames(sr9ProbesetIndices) <- paste("geneIndex",c(1:50),sep="")
sr9ProbesetIndices[1:3,1:3]
all(sr9ProbesetIndices == 
    matrix(rep(sr9ProbesetIndices["simulation1",],100),ncol=50,byrow=TRUE))
all(sr9ProbesetIndices == baseProbesetIndices)



###################################################
### chunk number 31: readSR9BasePfits
###################################################

sr9PfitVectors <- 
  read.table(file.path("MatlabFiles","DocetaxelSimulations",
                       "sr9PfitVectors.csv"), header=FALSE, sep=",")
colnames(sr9PfitVectors) <- names(doceSimulationStatus)
rownames(sr9PfitVectors) <- paste("simulation",c(1:100),sep="")



###################################################
### chunk number 32: plotSR9BaselinePfits
###################################################

matplot(t(sr9PfitVectors),pch="o",col="black",cex=0.5,xlim=c(0.5,38.5),
        xaxt="n", xlab="True Sample Status",
        ylab="Probability of Response, Coombes et al. Parameters",
        main="Predicted Response to Docetaxel, 100 Simulations")
abline(h=0.5,v=c(14.5),col="red",lwd=2)
abline(v=c(7.5,25.5),col="red",lty="dashed")
axis(side=1,at=c(4,11,20,32),
     labels=c("Resistant","Sensitive","Resp","NR"),tick=0,line=-1)
axis(side=3,at=c(7.5,26.5),
     labels=c("Training Cell Lines", "Test Samples"),tick=0,line=-1)
axis(side=4,at=c(0.25,0.75),labels=c("Call: Resistant","Call: Sensitive"),
     tick=FALSE,line=-1)



###################################################
### chunk number 33: checkBaseConsistency
###################################################

sr9NRespCorrect <- 
  apply(sr9PfitVectors[,15:25],1,function(x){sum(x > 0.5)})
sr9NNRCorrect <- 
  apply(sr9PfitVectors[,26:38],1,function(x){sum(x < 0.5)})
sr9NCorrect <- sr9NRespCorrect + sr9NNRCorrect

table(sr9NCorrect)
table(sr9NRespCorrect)
table(sr9NNRCorrect)



###################################################
### chunk number 34: loadSR9NullCellLines
###################################################

nullSR9CellLineIndices <- 
  read.table(file.path("MatlabFiles","DocetaxelSimulations",
                       "nullSR9CellLineIndices.csv"), header=FALSE, sep=",")
nullSR9CellLineIndices <- as.matrix(nullSR9CellLineIndices)
rownames(nullSR9CellLineIndices) <- paste("nullSim",c(1:1000),sep="")
colnames(nullSR9CellLineIndices) <- 
  c(paste("cellLineResIndex",c(1:7),sep=""),
    paste("cellLineSenIndex",c(1:7),sep=""))
nullSR9CellLineIndices[1:3,1:3]



###################################################
### chunk number 35: loadNullSR9Pfits
###################################################

nullSR9PfitVectors <- 
  read.table(file.path("MatlabFiles","DocetaxelSimulations",
                       "nullSR9TrainAndTestPfitVectors.csv"), 
             header=FALSE, sep=",")
colnames(nullSR9PfitVectors) <- 
  c(paste("nullRes",c(1:7),sep=""), paste("nullSim",c(1:7),sep=""),
    paste("testResp",c(1:11),sep=""), paste("testNR",c(1:13),sep=""))
rownames(nullSR9PfitVectors) <- paste("nullSim",c(1:1000),sep="")

nullSR9NRespCorrect <- 
  apply(nullSR9PfitVectors[,15:25],1,function(x){sum(x > 0.5)})
nullSR9NNRCorrect <- 
  apply(nullSR9PfitVectors[,26:38],1,function(x){sum(x < 0.5)})
nullSR9NCorrect <- nullSR9NRespCorrect + nullSR9NNRCorrect

table(nullSR9NCorrect)
sum(nullSR9NCorrect >= 12)



###################################################
### chunk number 36: checkCenteredData
###################################################

write.table(rbind(rep(c(0,1,2), times=c(7,7,24)),
                  cbind(tempDoceStandardized, changGEOStandardized)),
            file=file.path("MatlabFiles","DocetaxelSimulations",
              "docetaxelCentered.csv"),
            row.names=FALSE, col.names=FALSE, sep=",")



###################################################
### chunk number 37: readCenteredIndices
###################################################

centeredProbesetIndices <- 
  read.table(file.path("MatlabFiles","DocetaxelSimulations",
                       "centeredProbesetIndices.csv"), header=FALSE, sep=",")
centeredProbesetIndices <- as.matrix(centeredProbesetIndices)
centeredProbesetIndices <- t(apply(centeredProbesetIndices,1,sort))
rownames(centeredProbesetIndices) <- paste("simulation",c(1:100),sep="")
colnames(centeredProbesetIndices) <- paste("geneIndex",c(1:50),sep="")
centeredProbesetIndices[1:3,1:3]
all(centeredProbesetIndices == 
    matrix(rep(centeredProbesetIndices["simulation1",],100),ncol=50,byrow=TRUE))
all(centeredProbesetIndices == baseProbesetIndices)
length(intersect(centeredProbesetIndices[1,],baseProbesetIndices[1,]))



###################################################
### chunk number 38: readCenteredBasePfits
###################################################

centeredPfitVectors <- 
  read.table(file.path("MatlabFiles","DocetaxelSimulations",
                       "centeredPfitVectors.csv"), header=FALSE, sep=",")
colnames(centeredPfitVectors) <- names(doceSimulationStatus)
rownames(centeredPfitVectors) <- paste("simulation",c(1:100),sep="")



###################################################
### chunk number 39: plotCenteredBaselinePfits
###################################################

matplot(t(centeredPfitVectors),pch="o",col="black",cex=0.5,xlim=c(0.5,38.5),
        xaxt="n", xlab="True Sample Status",
        ylab="Probability of Response, Coombes et al. Parameters",
        main="Predicted Response to Docetaxel, 100 Simulations")
abline(h=0.5,v=c(14.5),col="red",lwd=2)
abline(v=c(7.5,25.5),col="red",lty="dashed")
axis(side=1,at=c(4,11,20,32),
     labels=c("Resistant","Sensitive","Resp","NR"),tick=0,line=-1)
axis(side=3,at=c(7.5,26.5),
     labels=c("Training Cell Lines", "Test Samples"),tick=0,line=-1)
axis(side=4,at=c(0.25,0.75),labels=c("Call: Resistant","Call: Sensitive"),
     tick=FALSE,line=-1)



###################################################
### chunk number 40: checkCenteredBaseConsistency
###################################################

centeredNRespCorrect <- 
  apply(centeredPfitVectors[,15:25],1,function(x){sum(x > 0.5)})
centeredNNRCorrect <- 
  apply(centeredPfitVectors[,26:38],1,function(x){sum(x < 0.5)})
centeredNCorrect <- centeredNRespCorrect + centeredNNRCorrect

table(centeredNCorrect)
table(centeredNRespCorrect)
table(centeredNNRCorrect)



###################################################
### chunk number 41: buildCombinedFigure eval=FALSE
###################################################
## 
## ## This figure requires two panels, both identifying
## ## the presence of ties in the data. 
## 
## tempDoceHeatmapPanel <- c(0.10, 0.45, 0.1, 0.88)
## tempDocePredictionsPanel <- c(0.57, 0.97, 0.1, 0.88)
## 
## par(plt=tempDoceHeatmapPanel)
## 
## image(1:24, 1:24, pottiGEOCorrs < 0.9999, axes=FALSE, xlab="", ylab="",
##       asp=1,main="Mapping Potti Test Samples to Chang GEO")
## 
## lines(c(0.5,24.5),c(11.5,11.5))
## lines(c(11.5,11.5),c(0.5,24.5))
## rect(0.5,0.5,24.5,24.5)
## axis(1, at=1:24, labels=rownames(pottiGEOCorrs), las=2, line=-1.5, tick=0);
## axis(2, at=1:24, labels=colnames(pottiGEOCorrs), las=2, tick=0,line=-0.5);
## lines(c(0.5,24.5),c(11,11),lty="dashed")
## lines(c(0.5,24.5),c(21,21),lty="dashed")
## axis(3,at=c(6,18),labels=c("Resistant (Potti)","Sensitive (Potti)"),
##      tick=0,line=-2)
## axis(4,at=c(6,18),labels=c("Sensitive (Chang)","Resistant (Chang)"),
##      tick=0,line=-1)
## axis(2,at=c(12,13),labels=c("S* (N12)","S* (N13)"),las=2,line=-4.5,tick=0)
## 
## par(plt=tempDocePredictionsPanel, new=TRUE)
## 
## matplot(t(basePfitVectors),pch="o",col="black",cex=0.5,xlim=c(0.5,38.5),
##         xaxt="n",xlab="",ylab="",
##         main="Predicted Response to Docetaxel, 100 Simulations")
## mtext("True Sample Status", side=1, line=1)
## mtext("Probability of Response", side=2, line=2.2)
## abline(h=0.5,v=c(14.5),col="red",lwd=2)
## abline(v=c(7.5,25.5),col="red",lty="dashed")
## axis(side=1,at=c(4,11,20,32),
##      labels=c("Resistant","Sensitive","Resp","NR"),tick=0,line=-1)
## axis(side=3,at=c(7.5,26.5),
##      labels=c("Training Cell Lines", "Test Samples"),tick=0,line=-1)
## axis(side=4,at=c(0.25,0.75),labels=c("Call: Resistant","Call: Sensitive"),
##      tick=FALSE,line=-1)
## 


###################################################
### chunk number 42: reallyPlotBig
###################################################

pdf(file="Figures/doceSummary.pdf",height=6,width=12)

## This figure requires two panels, both identifying
## the presence of ties in the data. 

tempDoceHeatmapPanel <- c(0.10, 0.45, 0.1, 0.88)
tempDocePredictionsPanel <- c(0.57, 0.97, 0.1, 0.88)

par(plt=tempDoceHeatmapPanel)

image(1:24, 1:24, pottiGEOCorrs < 0.9999, axes=FALSE, xlab="", ylab="",
      asp=1,main="Mapping Potti Test Samples to Chang GEO")

lines(c(0.5,24.5),c(11.5,11.5))
lines(c(11.5,11.5),c(0.5,24.5))
rect(0.5,0.5,24.5,24.5)
axis(1, at=1:24, labels=rownames(pottiGEOCorrs), las=2, line=-1.5, tick=0);
axis(2, at=1:24, labels=colnames(pottiGEOCorrs), las=2, tick=0,line=-0.5);
lines(c(0.5,24.5),c(11,11),lty="dashed")
lines(c(0.5,24.5),c(21,21),lty="dashed")
axis(3,at=c(6,18),labels=c("Resistant (Potti)","Sensitive (Potti)"),
     tick=0,line=-2)
axis(4,at=c(6,18),labels=c("Sensitive (Chang)","Resistant (Chang)"),
     tick=0,line=-1)
axis(2,at=c(12,13),labels=c("S* (N12)","S* (N13)"),las=2,line=-4.5,tick=0)

par(plt=tempDocePredictionsPanel, new=TRUE)

matplot(t(basePfitVectors),pch="o",col="black",cex=0.5,xlim=c(0.5,38.5),
        xaxt="n",xlab="",ylab="",
        main="Predicted Response to Docetaxel, 100 Simulations")
mtext("True Sample Status", side=1, line=1)
mtext("Probability of Response", side=2, line=2.2)
abline(h=0.5,v=c(14.5),col="red",lwd=2)
abline(v=c(7.5,25.5),col="red",lty="dashed")
axis(side=1,at=c(4,11,20,32),
     labels=c("Resistant","Sensitive","Resp","NR"),tick=0,line=-1)
axis(side=3,at=c(7.5,26.5),
     labels=c("Training Cell Lines", "Test Samples"),tick=0,line=-1)
axis(side=4,at=c(0.25,0.75),labels=c("Call: Resistant","Call: Sensitive"),
     tick=FALSE,line=-1)

dev.off()



###################################################
### chunk number 43: getLocation
###################################################

getwd()



###################################################
### chunk number 44: saveStuff
###################################################



###################################################
### chunk number 45: sessionInfo
###################################################

sessionInfo();



