###################################################
### chunk number 1: options
###################################################

options(width=80)



###################################################
### chunk number 2: loadEarlierRdas
###################################################

rdaList <- c("gyorffyAll","hsuReportedGenelists")
for(rdaFile in rdaList){
  rdaFullFile <- 
    file.path("RDataObjects",paste(rdaFile,"Rda",sep="."))
  if(file.exists(rdaFullFile)){
    cat("loading ",rdaFullFile, " from cache\n")
    load(rdaFullFile)
  }else{
    cat("building ",rdaFullFile, " from raw data\n")
    Stangle(file.path("RNowebSource",
                      paste("buildRda",rdaFile,"Rnw",sep=".")))
    source(paste("buildRda",rdaFile,"R",sep="."))
  }
}



###################################################
### chunk number 3: matchGyorffyProbes
###################################################

unmatchedRows <- which(is.na(match(cisplatinReportedProbesets[,"probesetID"], 
                                   rownames(gyorffyAll))))
unmatchedRows
cisplatinReportedProbesets[unmatchedRows,]
matchedCisplatinProbesets <- 
  rownames(cisplatinReportedProbesets)[-unmatchedRows]

cisplatinTable[cisplatinTable[,"Gene.Title"]=="231971_at",]



###################################################
### chunk number 4: drawCisplatinHeatmapAllLines
###################################################

tempMat <- gyorffyAll[matchedCisplatinProbesets, ]
source(file.path("Scripts", "jet.colors.R"))
heatmap(as.matrix(tempMat), col = jet.colors(64), 
        margins = c(6,6), cexRow = 0.75, cexCol = 0.9)



###################################################
### chunk number 5: drawCisplatinOffsetHeatmapAllLines
###################################################

offsetCisplatinProbesets <- 
  rownames(gyorffyAll)[match(matchedCisplatinProbesets,
                             rownames(gyorffyAll)) + 1]
tempMat <- gyorffyAll[offsetCisplatinProbesets,]
heatmap(as.matrix(tempMat), col = jet.colors(64), 
        margins = c(6,6), cexRow = 0.75, cexCol = 0.9)



###################################################
### chunk number 6: drawCorHeatmap
###################################################

cisplatinCor <- cor(t(scale(t(tempMat))))
heatmap(cisplatinCor, scale = "none", margins = c(6, 6), 
        cexCol = 0.9, cexRow = 0.9, col = jet.colors(64))



###################################################
### chunk number 7: startingCellLineGroups
###################################################

startingResistantLines <- 
  c("257p", "A375", "C8161", "ES-2",
    "ME-43", "MeWo", "SKMel13", "SKMel19", "SNU423", "SW13")
startingSensitiveLines <- 
  c("BT20", "DV-90", "FU-OV-1", 
    "OAW42", "OVCAR3", "R103", "SKOV-3")

gyorffyAllInfo[startingResistantLines,"Cisplatin"]
gyorffyAllInfo[startingSensitiveLines,"Cisplatin"]



###################################################
### chunk number 8: exportGyorffy
###################################################

write.table(gyorffyAll, 
            file = file.path("MatlabFiles", "GyorffyData",
              "gyorffyNumbers.csv"),
            sep = ",", row.names = FALSE, col.names = FALSE)
write.table(rownames(gyorffyAll), 
            file = file.path("MatlabFiles", "GyorffyData",
              "gyorffyProbesets.csv"), 
            sep = ",", row.names = FALSE, col.names = FALSE,
            quote = FALSE)
write.table(colnames(gyorffyAll), 
            file = file.path("MatlabFiles", "GyorffyData",
              "gyorffySamples.csv"), 
            sep = ",", row.names = FALSE, col.names = FALSE,
            quote = FALSE)



###################################################
### chunk number 9: exportStarting
###################################################

write.table(startingResistantLines,
            file=file.path("MatlabFiles","Cisplatin",
              "startingResistantLines.csv"),
            sep=",", row.names=FALSE, col.names=FALSE, quote=FALSE)

write.table(startingSensitiveLines,
            file=file.path("MatlabFiles","Cisplatin",
              "startingSensitiveLines.csv"),
            sep=",", row.names=FALSE, col.names=FALSE, quote=FALSE)

write.table(offsetCisplatinProbesets,
            file=file.path("MatlabFiles","Cisplatin",
              "targetProbesets.csv"),
            sep=",", row.names=FALSE, col.names=FALSE, quote=FALSE)



###################################################
### chunk number 10: readIterations
###################################################

cisplatinIteration1 <- 
  read.table(file.path("MatlabFiles","Cisplatin","cisplatinIteration1.csv"),
             header=TRUE, sep=",", row.names=1)
cisplatinIteration2 <- 
  read.table(file.path("MatlabFiles","Cisplatin","cisplatinIteration2.csv"),
             header=TRUE, sep=",", row.names=1)
cisplatinIteration3 <- 
  read.table(file.path("MatlabFiles","Cisplatin","cisplatinIteration3.csv"),
             header=TRUE, sep=",", row.names=1)

cisplatinIteration3[1:5,]


###################################################
### chunk number 11: extractingCellLines
###################################################

cisplatinResistantLines <- 
  rownames(cisplatinIteration3)[cisplatinIteration3[,"startStatus"]==
                                "Resistant"]
cisplatinSensitiveLines <- 
  rownames(cisplatinIteration3)[cisplatinIteration3[,"startStatus"]==
                                "Sensitive"]

cisplatinResistantLines
cisplatinSensitiveLines


###################################################
### chunk number 12: loadingHeatmapGenes
###################################################

softwareCisplatinProbesets <-
  read.table(file.path("MatlabFiles","Cisplatin",
                       "topCisplatinGenesInHeatmapOrder.txt"),
             header=FALSE, sep=",", strip.white=TRUE)
softwareCisplatinProbesets <- 
  as.character(softwareCisplatinProbesets[,1])
sort(softwareCisplatinProbesets)



###################################################
### chunk number 13: checkOverlapAndDiff
###################################################

sum(!is.na(match(offsetCisplatinProbesets, softwareCisplatinProbesets)))
setdiff(softwareCisplatinProbesets, offsetCisplatinProbesets)



###################################################
### chunk number 14: findIntroducedGenes
###################################################

softwareCisplatinMinus1Probesets <- 
  rownames(gyorffyAll)[match(softwareCisplatinProbesets,
                             rownames(gyorffyAll)) - 1]
setdiff(rownames(cisplatinReportedProbesets), 
        softwareCisplatinMinus1Probesets)
cisplatinReportedProbesets[setdiff(rownames(cisplatinReportedProbesets), 
                                   softwareCisplatinMinus1Probesets),]



###################################################
### chunk number 15: saveRda
###################################################

save(cisplatinCor, cisplatinIteration1, cisplatinIteration2,
     cisplatinIteration3, cisplatinReportedProbesets, 
     cisplatinResistantLines, cisplatinSensitiveLines,
     cisplatinTable, matchedCisplatinProbesets, 
     offsetCisplatinProbesets, softwareCisplatinMinus1Probesets,
     softwareCisplatinProbesets,
     file=file.path("RDataObjects","cisplatinAll.Rda"))



###################################################
### chunk number 16: getLocation
###################################################

getwd()



###################################################
### chunk number 17: saveStuff
###################################################




###################################################
### chunk number 18: sessionInfo
###################################################

sessionInfo();



