###################################################
### chunk number 1: options
###################################################

options(width=80)



###################################################
### chunk number 2: loadEarlierRdas
###################################################

rdaList <- c("novartisA","hsuReportedGenelists")
for(rdaFile in rdaList){
  rdaFullFile <- 
    file.path("RDataObjects",paste(rdaFile,"Rda",sep="."))
  if(file.exists(rdaFullFile)){
    cat("loading ",rdaFullFile, " from cache\n")
    load(rdaFullFile)
  }else{
    cat("building ",rdaFullFile, " from raw data\n")
    Stangle(file.path("RNowebSource",
                      paste("buildRda",rdaFile,"Rnw",sep=".")))
    source(paste("buildRda",rdaFile,"R",sep="."))
  }
}



###################################################
### chunk number 3: matchNovartisProbes
###################################################

unmatchedRows <- which(is.na(match(pemetrexedReportedProbesets[,"probesetID"], 
                                   rownames(novartisA))))
unmatchedRows
matchedPemetrexedProbesets <- 
  rownames(pemetrexedReportedProbesets)



###################################################
### chunk number 4: drawPemetrexedHeatmapAllLines
###################################################

tempMat <- log2(novartisA[matchedPemetrexedProbesets, ])
source(file.path("Scripts", "jet.colors.R"))
heatmap(as.matrix(tempMat), col = jet.colors(64), 
        margins = c(7,4), cexRow = 0.45, cexCol = 0.65)



###################################################
### chunk number 5: drawPemetrexedOffsetHeatmapAllLines
###################################################

offsetPemetrexedProbesets <- 
  rownames(novartisA)[match(matchedPemetrexedProbesets,
                            rownames(novartisA)) + 1]
tempMat <- log2(novartisA[offsetPemetrexedProbesets,])
heatmap(as.matrix(tempMat), col = jet.colors(64), 
        margins = c(7,4), cexRow = 0.45, cexCol = 0.65)



###################################################
### chunk number 6: drawCorHeatmap
###################################################

pemetrexedCor <- cor(t(scale(t(tempMat))))
heatmap(pemetrexedCor, scale = "none", margins = c(7, 7), 
        cexCol = 0.7, cexRow = 0.7, col = jet.colors(64))



###################################################
### chunk number 7: startingCellLineGroups
###################################################

startingSensitiveLines <- 
  c("SNB-75", "HS 578T", "SNB-19",
    "SF-268", "NCI-H226", "SK-MEL-2", "M14", "MALME-3M", "SK-MEL-28",
    "MDA-MB-231/ATCC", "SN12C", "MDA-MB-435")
startingResistantLines <- 
  c("SW-620", "NCI-H460", "KM12", "HCT-116",
    "HCC-2998", "K-562", "CCRF-CEM", "HL-60(TB)", "MCF7", "MOLT-4")



###################################################
### chunk number 8: exportNovartisA
###################################################

affyControlRows = grep("^AFFX",rownames(novartisA))
write.table(novartisA[-affyControlRows,], 
            file = file.path("MatlabFiles", "NCI60Data",
              "nci60_numbers.csv"),
            sep = ",", row.names = FALSE, col.names = FALSE)
write.table(rownames(novartisA)[-affyControlRows], 
            file = file.path("MatlabFiles", "NCI60Data",
              "nci60_probesets.csv"), 
            sep = ",", row.names = FALSE, col.names = FALSE,
            quote = FALSE)
write.table(colnames(novartisA), 
            file = file.path("MatlabFiles", "NCI60Data",
              "nci60_samples.csv"), 
            sep = ",", row.names = FALSE, col.names = FALSE,
            quote = FALSE)



###################################################
### chunk number 9: exportStarting
###################################################

write.table(startingResistantLines,
            file=file.path("MatlabFiles","Pemetrexed",
              "startingResistantLines.csv"),
            sep=",", row.names=FALSE, col.names=FALSE, quote=FALSE)

write.table(startingSensitiveLines,
            file=file.path("MatlabFiles","Pemetrexed",
              "startingSensitiveLines.csv"),
            sep=",", row.names=FALSE, col.names=FALSE, quote=FALSE)

write.table(offsetPemetrexedProbesets,
            file=file.path("MatlabFiles","Pemetrexed",
              "targetProbesets.csv"),
            sep=",", row.names=FALSE, col.names=FALSE, quote=FALSE)



###################################################
### chunk number 10: readIterations
###################################################

pemetrexedIteration1 <- 
  read.table(file.path("MatlabFiles","Pemetrexed","pemetrexedIteration1.csv"),
             header=TRUE, sep=",", row.names=1)
pemetrexedIteration2 <- 
  read.table(file.path("MatlabFiles","Pemetrexed","pemetrexedIteration2.csv"),
             header=TRUE, sep=",", row.names=1)
pemetrexedIteration3 <- 
  read.table(file.path("MatlabFiles","Pemetrexed","pemetrexedIteration3.csv"),
             header=TRUE, sep=",", row.names=1)
pemetrexedIteration4 <- 
  read.table(file.path("MatlabFiles","Pemetrexed","pemetrexedIteration4.csv"),
             header=TRUE, sep=",", row.names=1)
pemetrexedIteration5 <- 
  read.table(file.path("MatlabFiles","Pemetrexed","pemetrexedIteration5.csv"),
             header=TRUE, sep=",", row.names=1)
pemetrexedIteration6 <- 
  read.table(file.path("MatlabFiles","Pemetrexed","pemetrexedIteration6.csv"),
             header=TRUE, sep=",", row.names=1)
pemetrexedIteration7 <- 
  read.table(file.path("MatlabFiles","Pemetrexed","pemetrexedIteration7.csv"),
             header=TRUE, sep=",", row.names=1)

pemetrexedIteration7[1:5,]



###################################################
### chunk number 11: extractingCellLines
###################################################

pemetrexedResistantLines <- 
  rownames(pemetrexedIteration3)[pemetrexedIteration7[,"startStatus"]==
                                "Resistant"]
pemetrexedSensitiveLines <- 
  rownames(pemetrexedIteration3)[pemetrexedIteration7[,"startStatus"]==
                                "Sensitive"]

pemetrexedResistantLines
pemetrexedSensitiveLines



###################################################
### chunk number 12: loadingHeatmapGenes
###################################################

softwarePemetrexedProbesets <-
  read.table(file.path("MatlabFiles","Pemetrexed",
                       "topPemetrexedGenesInHeatmapOrder.txt"),
             header=FALSE, sep=",", strip.white=TRUE)
softwarePemetrexedProbesets <- 
  as.character(softwarePemetrexedProbesets[,1])
sort(softwarePemetrexedProbesets)



###################################################
### chunk number 13: checkOverlapAndDiff
###################################################

sum(!is.na(match(offsetPemetrexedProbesets, softwarePemetrexedProbesets)))
setdiff(softwarePemetrexedProbesets, offsetPemetrexedProbesets)



###################################################
### chunk number 14: saveRda
###################################################

save(pemetrexedCor, pemetrexedIteration1, pemetrexedIteration2,
     pemetrexedIteration3, pemetrexedIteration4, pemetrexedIteration5,
     pemetrexedIteration6, pemetrexedIteration7,
     pemetrexedReportedProbesets, 
     pemetrexedResistantLines, pemetrexedSensitiveLines,
     pemetrexedTable, matchedPemetrexedProbesets, 
     offsetPemetrexedProbesets, softwarePemetrexedProbesets,
     file=file.path("RDataObjects","pemetrexedAll.Rda"))



###################################################
### chunk number 15: getLocation
###################################################

getwd()



###################################################
### chunk number 16: saveStuff
###################################################




###################################################
### chunk number 17: sessionInfo
###################################################

sessionInfo();



